Struct amazon_sp_aplus_content::models::aplus_paginated_response_all_of::AplusPaginatedResponseAllOf
source · [−]Fields
next_page_token: Option<String>A page token that is returned when the results of the call exceed the page size. To get another page of results, call the operation again, passing in this value with the pageToken parameter.
Implementations
sourceimpl AplusPaginatedResponseAllOf
impl AplusPaginatedResponseAllOf
pub fn new() -> AplusPaginatedResponseAllOf